@@ -1,19 +1,19 @@
-package Dist::Zilla::Plugin::Author::Plicease;
+package Dist::Zilla::Plugin::Author::Plicease 2.22 {
 
-use strict;
-use warnings;
-use Path::Class ();
-use File::ShareDir ();
+  use strict;
+  use warnings;
+  use Path::Tiny ();
+  use File::ShareDir::Dist ();
 
-# ABSTRACT: Dist::Zilla plugins used by Plicease
-our $VERSION = '2.21'; # VERSION
+  # ABSTRACT: Dist::Zilla plugins used by Plicease
 
 
-sub dist_dir
-{
-  Path::Class::Dir->new(
-    File::ShareDir::dist_dir('Dist-Zilla-Plugin-Author-Plicease')
-  );
+  sub dist_dir
+  {
+    Path::Tiny->new(
+      File::ShareDir::Dist::dist_share('Dist-Zilla-Plugin-Author-Plicease')
+    );
+  }
 }
 
 1;
@@ -30,7 +30,7 @@ Dist::Zilla::Plugin::Author::Plicease - Dist::Zilla plugins used by Plicease
 
 =head1 VERSION
 
-version 2.21
+version 2.22
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
